Stan Math Library: stan/math/rev/mat/fun/squared_distance.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
squared_distance.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/scal/fun/sqrt.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/err/check_vector.hpp>`
`#include <stan/math/prim/mat/err/check_matching_sizes.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/arr/meta/index_type.hpp>`
`#include <stan/math/prim/scal/meta/index_type.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R1, int C1, int R2, int C2>
var | stan::math::squared_distance (const Eigen::Matrix< var, R1, C1 > &v1, const Eigen::Matrix< var, R2, C2 > &v2)
template<int R1, int C1, int R2, int C2>
var | stan::math::squared_distance (const Eigen::Matrix< var, R1, C1 > &v1, const Eigen::Matrix< double, R2, C2 > &v2)
template<int R1, int C1, int R2, int C2>
var | stan::math::squared_distance (const Eigen::Matrix< double, R1, C1 > &v1, const Eigen::Matrix< var, R2, C2 > &v2)

## Variable Documentation

size_t length_

Definition at line 26 of file squared_distance.hpp.

vari** v1_

Definition at line 24 of file squared_distance.hpp.

double* v2_

Definition at line 25 of file squared_distance.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.